\name{forprefmap}

\alias{forprefmap}

\title{Creates the dataset for the \emph{carto} function by considering Ideal Profile data}

\description{
Separate the dataset obtained with the IPM into two tables (one with the sensory and one with the hedonic).
}

\usage{
forprefmap(dataset, col.p, col.j, col.lik, id.recogn, rm.j=TRUE)
}

\arguments{
  \item{dataset}{A matrix with at least two qualitative variables (\emph{consumer} and \emph{products})
  and a set of quantitative variables containing at least 2*A variables (for both \emph{perceived} and \emph{ideal} intensities)}
  \item{col.p}{The position of the \emph{product} variable }
  \item{col.j}{The position of the \emph{consumer} variable }
  \item{col.lik}{The position of the \emph{liking} variable }
  \item{id.recogn}{The sequence in the variable names which distinguish the ideal
  variables from the sensory variables. This sequence should be fixed and unique. }
  \item{rm.j}{Boolean, define whether the consumer with 0 variance in liking should be removed.}
}

\details{
Separate the dataset obtained from the Ideal Profile Method into two tables:
one with the sensory information (averaged by products, products being in row and the sensory attributes in columns)
and one with the hedonic information (products in row, consumer in columns).
}

\value{
A list containing the following components:
  \item{senso}{the averaged sensory table (\emph{products} in rows, \emph{attributes} in columns)}
  \item{hedo}{the hedonic table (\emph{products}  in rows, \emph{consumers} in columns)}
}



\author{Worch Thierry (thierry@qistatistics.co.uk)}

\seealso{ \code{\link{carto}}}

\examples{
\dontrun{
data(perfume_ideal)
res.data <- forprefmap(perfume_ideal, col.p=2, col.j=1, col.lik=ncol(perfume_ideal), id.recogn="id_")
#! To perform the carto
res.carto <- carto(Mat=PCA(res.data$senso,graph=F,ncp=2)$ind$coord, MatH=res.data$hedo)
}
}

\keyword{models}
