\name{hedo.consist}

\alias{hedo.consist}

\title{Hedonic consistency of the ideal data}

\description{
Procedure to check the hedonic consistency of the ideal data.
}

\usage{
hedo.consist(dataset, col.p, col.j, col.lik, id.recogn, family.model="PCR",
              ncp=NULL, scale.unit=TRUE, nbsim=0, graph=F)
}

\arguments{
  \item{dataset}{A matrix with at least two qualitative variables (\emph{consumer} and \emph{products})
  and a set of quantitative variables containing at least 2*A variables (for both \emph{perceived} and \emph{ideal} intensities)}
  \item{col.p}{The position of the \emph{product} variable }
  \item{col.j}{The position of the \emph{consumer} variable }
  \item{col.lik}{The position of the \emph{liking} variable }
  \item{id.recogn}{The sequence in the variable names which distinguish the ideal
  variables from the sensory variables. This sequence should be fixed and unique. }
  \item{family.model}{The family of model to chose between "PLS", "PCR" and "Danzart"}
  \item{ncp}{Number of component considered in the analysis (by default, 1 for "PLS", 2 for "Danzart" and 5 or "PCR")}
  \item{scale.unit}{Boolean, if TRUE (value set by default) then data are scaled to unit variance}
  \item{nbsim}{The number of simulations performed. By default (=0),
  no simulations are performed and only the results for the real data are given}
  \item{graph}{Boolean, whether graphs should be shown or not.}
}


\details{
For each consumer, a model expressing the liking scores in function of the perceived intensity is created.\cr
This model is either obtained by PLS-regression, or by PCR
(a PCA is performed on the sensory description provided by the consumer considered
and his/her liking scores are regressed on the dimensions of interest).\cr
By default, the PLS regression is performed on 1 component only while the PCR considers
the first 5 dimensions of the PCA and the Danzart model corresponds to the quadratic model
used for the external preference mapping.\cr
For the PCR and Danzart models, a selection of the best model is also performed.\cr
Once the model is created, the model is applied to the ideal ratings provided by the consumer
considered and the hedonic score of the ideal product is estimated.\cr
This hedonic score is then compared to the hedonic scores provided to the products tested.\cr
If simulations are asked, the same procedure is estimated after re-sampling the vector of hedonic scores.\cr
In that case, the distribution of the estimated ideal hedonic score can be estimated
under H0 and the significance of the estimated ideal hedonic score can be done.\cr
}

\value{
A list containing the following components:
  \item{family.mod}{the family of model considered}
  \item{R2}{the R2 coefficients of the indivvidual models}
  \item{R2aj}{the adjusted R2 coefficients of the individual models (only for PCR and Danzart)}
  \item{hedo}{a list containing the hedonic scores for the \emph{product}, \emph{ideal products}, \emph{average ideal product}
  and the \emph{standardized ideal product} for each consumer}
  \item{simulation}{a list including the estimated hedonic score for each simulation, the p-value and the matrix of simulations used}
}

\references{Worch, T., L, S., Punter, P., & Pags, J. (2012).
Extension of the consistency of the data obtained with the Ideal Profile Method:
Would the ideal products be more liked than the tested products?
\emph{Food Quality and Preference}, 26, 74-80.
}

\author{Worch Thierry (thierry@qistatistics.co.uk)}

\seealso{ \code{\link{senso.consist}}}

\examples{
\dontrun{
data(perfume_ideal)
res <- hedo.consist(perfume_ideal, col.p=2, col.j=1, col.lik=ncol(perfume_ideal),
                    id.recogn="id_", family.model="PCR", ncp=NULL, scale.unit=TRUE,
                    nbsim=0, graph=F)
}
}

\keyword{consistency}
