\name{ideal.sd}

\alias{ideal.sd}

\title{Variability in the ideal data compared to the perceived intensities}

\description{
Measure the variability of the ideal data compared to the varaibility of the perceived intensities.
}

\usage{
ideal.sd(dataset,col.p,col.j,id.recogn,split.byatt=FALSE)
}

\arguments{
  \item{dataset}{A matrix with at least two qualitative variables (\emph{consumer} and \emph{products})
  and a set of quantitative variables containing at least 2*A variables (for both \emph{perceived} and \emph{ideal} intensities)}
  \item{col.p}{The position of the \emph{product} variable }
  \item{col.j}{The position of the \emph{consumer} variable }
  \item{id.recogn}{The sequence in the variable names which distinguish the ideal
  variables from the sensory variables. This sequence should be fixed and unique. }
  \item{split.byatt}{Boolean, defines whether the results should be given by attributes as well}
}

\details{
For each attribute and each consumer, the standard deviation of the perceived and ideal intensity is calculated.\cr
The ratio \emph{sd(ideal)}/\emph{sd(perceived)} is also calculated for each consumer.
}

\value{
A list containing the following components:
  \item{sd.int}{the standard deviation of the perceived intensities for each attribute and each consumer}
  \item{sd.id}{the standard deviation of the ideal intensities for each attribute and each consumer}
  \item{sd.ratio}{the ratio per attribute and per consumer}
}


\author{Worch Thierry (thierry@qistatistics.co.uk)}

\seealso{ \code{\link{sd}}}

\examples{
\dontrun{
data(perfume_ideal)
res <- ideal.sd(perfume_ideal,col.p=2,col.j=1,id.recogn="id_",split.byatt=TRUE)
}
}

\keyword{models}
