\name{influence.ideal}

\alias{influence.ideal}

\title{Influence of the perception of a product on the ideal rating}

\description{
Measure the influence of the perceived intensity on the ideal ratings provided by the consumers.\cr
This influence can be measured through \emph{PCA} or \emph{MFA}.
}

\usage{
influence.ideal(dataset, col.p, col.j, id.recogn, analysis="PCA")
}

\arguments{
  \item{dataset}{A matrix with at least two qualitative variables (\emph{consumer} and \emph{products})
  and a set of quantitative variables containing at least 2*A variables (for both \emph{perceived} and \emph{ideal} intensities)}
  \item{col.p}{The position of the \emph{product} variable }
  \item{col.j}{The position of the \emph{consumer} variable }
  \item{id.recogn}{The sequence in the variable names which distinguish the ideal
  variables from the sensory variables. This sequence should be fixed and unique. }
  \item{analysis}{The multivariate analysis to use to measure the influence ("PCA" or "MFA")}
}

\details{
Influence.ideal, step by step:\cr
Step 1: the sensory and ideal variables are separated into two tables.\cr
Step 2: the average table by product is computed for the sensory table.\cr
Step 3: for each ideal variable, a two-way anova (~product + consumer) is
performed and the coefficient alpha_i associated with the product effect are extracted.\cr
Step 4: the averaged table (sensory) and the table of ?_i (ideal) are merged
in columns and is analyzed either by MFA (one group per type of data),
or by PCA (on the sensory description, the ideal variables being projected as supplementary variables).\cr
}

\value{
A list containing the following components:
  \item{data}{the dataset submitted to the multivariate analysis}
  \item{analyse}{the results of the multivariate analysis}
  \item{correlation}{the correlation between corresponding attributes}
  \item{num.att}{the number of attributes with a significant \emph{product} effect}
}



\author{Worch Thierry (thierry@qistatistics.co.uk)}

\seealso{ \code{\link{aov}}, \code{\link{PCA}}, \code{\link{MFA}}}

\examples{
\dontrun{
data(perfume_ideal)
res <- influence.ideal(perfume_ideal,col.p=2,col.j=1,id.recogn="id_",analysis="PCA")
}
}

\keyword{models}
