\name{senso.consist}

\alias{senso.consist}

\title{Sensory consistency of the ideal data}

\description{
Evaluate the sensory consistency of the ideal data, both at the consumer and panel level..
}

\usage{
senso.consist(dataset, col.p, col.j, col.lik, id.recogn, consist="both",
              scale.unit=TRUE, ncp=5, axes=c(1,2), correct=TRUE,
              replace.na=FALSE, graph=TRUE)
}

\arguments{
  \item{dataset}{A matrix with at least two qualitative variables (\emph{consumer} and \emph{products})
  and a set of quantitative variables containing at least 2*A variables (for both \emph{perceived} and \emph{ideal} intensities)}
  \item{col.p}{The position of the \emph{product} variable }
  \item{col.j}{The position of the \emph{consumer} variable }
  \item{col.lik}{The position of the \emph{liking} variable }
  \item{id.recogn}{The sequence in the variable names which distinguish the ideal
  variables from the sensory variables. This sequence should be fixed and unique. }
  \item{consist}{The type of consistency asked. It can either be "panel", "consumer" or "both"}
  \item{scale.unit}{Boolean, if T the descriptors are scaled to unit variance}
  \item{ncp}{Number of dimensions kept in the results (by default 5)}
  \item{axes}{A length 2 vector specifying the components to plot}
  \item{correct}{Boolean, define whether the ideal data should be corrected or not for the difference in the use of the scale}
  \item{replace.na}{Boolean, define whether the missing values
  (in the correlation matrix calculated for the consistency at the consumer level)
  should be ignored or replaced by 0}
  \item{graph}{Boolean, define whether the distribution of the correlation coefficient should be plot}
}

\details{
  A the panel level:\cr
  A PCA is performed on the table crossing the J consumers in rows and the A ideal variables
  in columns (the averaged or corrected averaged is then considered).\cr
  On this space, the sensory description of the P products (P rows) on the A attributes
  is projected as supplementary entities while the hedonic table crossing
  the J consumers (in rows) and the P products (in columns) is projected as supplementary variables.\cr
  The sensory consistency is measured by the correspondence between the same products seen
  through the sensory and through the hedonic descriptions.\cr
  
  At the consumer level:\cr
  For each consumer, the correlation between the (corrected) ideal ratings and
  the correlation between the hedonic scores and the perceived intensity of each attribute is calculated.\cr
  A test on this correlation coefficient is performed for each consumer.\cr
  The distribution of these correlations coefficients are also given graphically.
}

\value{
A list containing the following components:\cr
  \item{panel}{results for the consistency at the panel level including:}
  \item{panel$dataset}{the datasets used for the different PCA}
  \item{panel$PCA.ideal}{the results of the PCA for the creation of the ideal space}
  \item{panel$PCA.ideal_hedo}{the results of the PCA with projection of the hedonic scores}
  \item{panel$PCA.ideal_senso}{the results of the PCA with the proojection of the sensory descriptions}
  \item{panel$correlation}{the correlation between the \emph{product} projected from the \emph{sensory} and \emph{hedonic} points of view}
\cr
  \item{conso}{results of the consistency at the consumer level including: }
  \item{conso$driver.lik}{the linear drivers of liking (correlation between perceived intensity and liking score for each attribute)}
  \item{conso$correlations}{the correlations between drivers of liking and the difference (ideal-perceived) intensity}
}

\references{Worch, T., L, S., Punter, P., & Pags, J. (2012).
Assessment of the consistency of ideal profiles according to non-ideal data for IPM.
\emph{Food Quality and Preference}, 24, 99-110.
}

\author{Thierry Worch (thierry@qistatistics.co.uk)}

\seealso{ \code{\link{hedo.consist}}}

\examples{
\dontrun{
data(perfume_ideal)
res <- senso.consist(perfume_ideal, col.p=2, col.j=1, col.lik=ncol(perfume_ideal),
id.recogn="id_", consist="both", scale.unit=TRUE, ncp=5, axes=c(1,2),
correct=TRUE, replace.na=FALSE, graph=TRUE)
}
}

\keyword{consistency}